@@ -1,3 +1,4 @@
+from kraken_html.html_field import Html_field
 
 from dateutil.parser import parse
 
@@ -9,6 +10,12 @@ class Html_record:
 
     def record(self, keys, value):
 
+        # Define link data. 
+        record_type = value.get('@type', None)
+        record_id = value.get('@id', None)
+
+
+
         content = ''
 
         content += '<div class="container-fluid">'
@@ -17,14 +24,10 @@ class Html_record:
 
         for i in keys:
 
-            i_value = value.get(i, None)
+            cell_value = value.get(i, None)
 
-            # Convert to datetime and then to simple date format
-            try:
-                date_value = parse(i_value)
-                i_value = date_value.strftime("%Y-%m-%d, %H:%M")
-            except:
-                a = 1
+            html_field = Html_field()
+            i_value = html_field.get(record_type, record_id, i, cell_value)
 
             content += self._record_line(i, i_value)
 
